@@ -8,6 +8,7 @@ import argcomplete
 
 from ._version import commit_id, version
 from .cmds import (
+    CompareImagesSubCommand,
     CopyImagesSubCommand,
     ListImagesSubCommand,
     SaveImagesSubCommand,
@@ -33,6 +34,7 @@ def main():
     ListImagesSubCommand.register(subcommand_parser)
     SaveImagesSubCommand.register(subcommand_parser)
     CopyImagesSubCommand.register(subcommand_parser)
+    CompareImagesSubCommand.register(subcommand_parser)
 
     # Autocomplete
     argcomplete.autocomplete(parser)
